@@ -14,10 +14,13 @@ from ..base_league import BaseLeague
 class League(BaseLeague):
     '''Creates a League instance for Public/Private ESPN league'''
 
-    def __init__(self, league_id: int, year: int, espn_s2=None, swid=None, username=None, password=None, debug=False):
-        super().__init__(league_id=league_id, year=year, sport='nhl', espn_s2=espn_s2, swid=swid, username=username,
-                         password=password, debug=debug)
+    def __init__(self, league_id: int, year: int, espn_s2=None, swid=None, fetch_league=True, debug=False):
+        super().__init__(league_id=league_id, year=year, sport='nhl', espn_s2=espn_s2, swid=swid, debug=debug)
 
+        if fetch_league:
+            self.fetch_league()
+
+    def fetch_league(self):
         data = self._fetch_league()
         self._fetch_teams(data)
 
